diff -rup ~dash-0.5.6.1/src/error.h tdash-0.5.6.1/src/error.h
--- ~dash-0.5.6.1/src/error.h	2010-08-02 03:05:09.000000000 +0200
+++ tdash-0.5.6.1/src/error.h	2010-08-02 03:22:21.000000000 +0200
@@ -69,7 +69,7 @@ extern int exception;
 #define EXSHELLPROC 2	/* execute a shell procedure */
 #define EXEXEC 3	/* command execution failed */
 #define EXEXIT 4	/* exit the shell */
-
+#define EXIFILE 5	/* inputfile cannot be opened or is a directory */
 
 /*
  * These macros allow the user to suspend the handling of interrupt signals
diff -rup ~dash-0.5.6.1/src/options.c tdash-0.5.6.1/src/options.c
--- ~dash-0.5.6.1/src/options.c	2010-08-02 03:05:09.000000000 +0200
+++ tdash-0.5.6.1/src/options.c	2010-08-02 03:26:06.000000000 +0200
@@ -35,6 +35,9 @@
 #include <signal.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <errno.h>
 
 #include "shell.h"
 #define DEFINE_OPTIONS
@@ -117,6 +120,23 @@ STATIC int getopts(char *, char *, char
  */
 
 int
+isdir(const char *name)
+{
+	int fd;
+	struct stat64 st;
+	
+	if ((fd = open(name, O_RDONLY))<0)
+		return -1;
+	if (fstat64(fd, &st) < 0)
+		return -1;
+	if (S_ISDIR(st.st_mode)) {
+		return -1;
+		errno = EISDIR;
+	}
+		return 0;
+}
+
+int
 procargs(int argc, char **argv)
 {
 	int i;
@@ -156,10 +176,16 @@ procargs(int argc, char **argv)
 		if (*xargv)
 			goto setarg0;
 	} else if (!sflag) {
-		setinputfile(*xargv, 0);
+		if(!isdir(*xargv)) {
+			setinputfile(*xargv, 0);
+		}
+		else {
+			exerror(EXIFILE, "Can't open %s", *xargv);
+		}
 setarg0:
-		arg0 = *xargv++;
-		commandname = arg0;
+	arg0 = *xargv++;
+	commandname = arg0;
+	
 	}
 
 	shellparam.p = xargv;
